@@ -1,12 +1,10 @@
-from bleak.backends.corebluetooth.utils import cb_uuid_to_str
 from typing import List
 
 from CoreBluetooth import CBService
 
-from bleak.backends.corebluetooth.characteristic import (
-    BleakGATTCharacteristicCoreBluetooth,
-)
-from bleak.backends.service import BleakGATTService
+from ..service import BleakGATTService
+from .characteristic import BleakGATTCharacteristicCoreBluetooth
+from .utils import cb_uuid_to_str
 
 
 class BleakGATTServiceCoreBluetooth(BleakGATTService):
@@ -34,7 +32,9 @@ class BleakGATTServiceCoreBluetooth(BleakGATTService):
         """List of characteristics for this service"""
         return self.__characteristics
 
-    def add_characteristic(self, characteristic: BleakGATTCharacteristicCoreBluetooth):
+    def add_characteristic(
+        self, characteristic: BleakGATTCharacteristicCoreBluetooth
+    ) -> None:
         """Add a :py:class:`~BleakGATTCharacteristicCoreBluetooth` to the service.
 
         Should not be used by end user, but rather by `bleak` itself.
